Crate ethersync

Crate ethersync 

Modules

cli
config
Data structures and helper methods around influencing the configuration of the application.
daemon
document
editor
This module is all about daemon to editor communication.
editor_connection
logging
ot
path
peer
This module provides a ConnectionManager, which can be used to connect to other daemons.
sandbox
๐Ÿ‘ฎ๐Ÿšจ๐Ÿš“ The functions in this module are supposed to prevent file I/O outside the base directory. All our file I/O should go through them.
types
watcher
wormhole