pub struct AppConfig {
pub peer: Option<Peer>,
pub emit_join_code: bool,
pub emit_secret_address: bool,
}Fields
peer: Option<Peer>emit_join_code: boolemit_secret_address: boolImplementations
Sourceimpl AppConfig
impl AppConfig
pub fn from_config_file(config_file: &Path) -> Option<Self>
Sourcepub async fn resolve_peer(
self,
directory: &Path,
config_file: &Path,
) -> Result<Self>
pub async fn resolve_peer( self, directory: &Path, config_file: &Path, ) -> Result<Self>
If we have a join code, try to use that and overwrite the config file. If we don’t have a join code, try to use the configured peer. Otherwise, fail.
pub const fn is_host(&self) -> bool