pub struct Document { /* private fields */ }Expand description
Encapsulates the Automerge AutoCommit and provides a generic interface,
s.t. we don’t need to worry about automerge internals elsewhere.
The interface allows us to apply changes to the CRDT in two ways:
- synchronization with other CRDTs through sync messages
- applying a delta (coming from an editor) directly
Furthermore there’s a way to retrieve and initialize the content.
Implementations
Sourceimpl Document
impl Document
pub fn load(bytes: &[u8]) -> Self
pub fn save(&mut self) -> Vec<u8> ⓘ
pub fn save_incremental(&mut self) -> Vec<u8> ⓘ
pub fn actor_id(&self) -> String
pub fn receive_sync_message_log_patches( &mut self, message: AutomergeSyncMessage, peer_state: &mut SyncState, ) -> Vec<Patch>
pub fn generate_sync_message( &mut self, peer_state: &mut SyncState, ) -> Option<AutomergeSyncMessage>
pub fn apply_delta_to_doc( &mut self, delta: &TextDelta, file_path: &RelativePath, )
pub fn current_file_content(&self, file_path: &RelativePath) -> Result<String>
pub fn file_content_at( &self, file_path: &RelativePath, heads: &[ChangeHash], ) -> Result<String>
pub fn initialize_text(&mut self, text: &str, file_path: &RelativePath)
pub fn update_text( &mut self, desired_text: &str, file_path: &RelativePath, ) -> Option<TextDelta>
pub fn remove_file(&mut self, file_path: &RelativePath)
Sourcepub fn set_bytes(&mut self, bytes: &[u8], file_path: &RelativePath)
pub fn set_bytes(&mut self, bytes: &[u8], file_path: &RelativePath)
Used to set or update a binary file’s content.
pub fn files(&self) -> Vec<RelativePath>
pub fn file_exists(&self, file_path: &RelativePath) -> bool
pub fn get_heads(&mut self) -> Vec<ChangeHash>