Modules
- cli
- config
- Data structures and helper methods around influencing the configuration of the application.
- daemon
- document
- editor
- This module is all about daemon to editor communication.
- editor_
connection - logging
- ot
- path
- peer
- This module provides a
ConnectionManager, which can be used to connect to other daemons. - sandbox
- ๐ฎ๐จ๐ The functions in this module are supposed to prevent file I/O outside the base directory. All our file I/O should go through them.
- types
- watcher
- wormhole